enum LinuxSecretError {
UnsupportedVersion(u8),
OldVersion {
version: u8,
session: StoredSession,
item: Item,
access_token: Option<String>,
},
Field(LinuxSecretFieldError),
Oo7(Error),
}Expand description
Any error that can happen when interacting with the secret backends on Linux.
Variants
UnsupportedVersion(u8)
A session with an unsupported version was found.
OldVersion
A session with an old version was found.
Fields

session: StoredSessionThe session that was found.
Field(LinuxSecretFieldError)
An error occurred while retrieving a field of the session.
This should only happen if for some reason we get an item from a different application.
Oo7(Error)
An error occurred while interacting with the secret backend.