enum LinuxSecretFieldError {
Missing(&'static str),
Invalid,
}Expand description
Any error that can happen when retrieving an attribute from the secret backends on Linux.
Variants
Missing(&'static str)
An attribute is missing.
This should only happen if for some reason we get an item from a different application.
Invalid
An invalid attribute was found.
This should only happen if for some reason we get an item from a different application.