async fn delete_item_with_attributes(
attributes: &impl AsAttributes,
) -> Result<(), Error>Expand description
Remove the item with the given attributes from the secret backend.
async fn delete_item_with_attributes(
attributes: &impl AsAttributes,
) -> Result<(), Error>Remove the item with the given attributes from the secret backend.