struct V4SecretData {
access_token: String,
passphrase: String,
}Expand description
Secret data that was stored in the secret backend from versions 4 through 6.
Fields
access_token: StringThe access token to provide to the homeserver for authentication.
passphrase: StringThe passphrase used to encrypt the local databases.